@@ -64,12 +64,17 @@ class TGWCrawler(object):
     def fetch(self, items):
         output = []
         for item in items:
-            source = item['source']
+            source = item.get('source', None)
+            url = item.get("url", None)
             result = self._fetch(**item)
             if result is None:
                 continue
             for item in result:
-                item['source'] = source
+                if source is not None:
+                    item['source'] = source
+                else:
+                    if url is not None:
+                        item['url'] = url
                 output.append(item)
             time.sleep(random.randint(1, 5))
         return output
@@ -77,12 +82,17 @@ class TGWCrawler(object):
     def __fetch(self, q, p):
         while not q.empty():
             item = q.get()
-            source = item['source']
+            source = item.get('source', None)
+            url = item.get("url", None)
             result = self._fetch(**item)
             if result is None:
                 continue
             for item in result:
-                item['source'] = source
+                if source is not None:
+                    item['source'] = source
+                else:
+                    if url is not None:
+                        item['url'] = url
                 p.put(item)
             time.sleep(random.randint(1, 5))
 
